{% raw %}

# FeedCrawler

Projekt von RiX {{ version }} (Update verfügbar!)

Suchlauf gestartet: {{ crawltimes.start_time | date:'mediumTime' }} (Dauer: {{ (now-crawltimes.start_time)/1000 | number:0 | secondsToHHmmss }})
Start des nächsten Suchlaufs: {{ crawltimes.next_start | date:'HH:mm:ss' }}
Dauer des letzten Suchlaufs: {{ crawltimes.total_time }}
Kein aktiver Sponsor Aktiver Sponsor

### Log

Zeitstempel | Release | Kategorie | Seite
--- | --- | --- | ---
{{ x[1] }} | {{ x[3] | limitTo: loglength }} ... | {{ x[2] }} | {{ x[4] }} |

Leeren

### My JDownloader

##

()

- /
- %
- Entpacken -
- Wartet auf Entpacken Wartet auf Download

- Löschen

()

- Warte auf hinzugefügte Links!
- Download starten Löschen

- Click'n'Load-Automatik Die Click'n'Load-Automatik funktioniert nicht bei aktivem Linkgrabber. Warte noch {{time}} {{time == 1 ?'Sekunde':'Sekunden'}} auf hinzugefügte Links!
- Erneut hinzufügen Löschen

- Sponsors Helper Click'n'Load Bitte zuerst Tampermonkey und dann FeedCrawler Sponsors Helper (SJ) installieren! Bitte zuerst Tampermonkey und dann FeedCrawler Sponsors Helper (DJ) installieren! Bitte zuerst Tampermonkey und dann FeedCrawler Sponsors Helper (FC) installieren! Click'n'Load-Automatik Bitte zuerst Tampermonkey und dann FeedCrawler Helper (SJ) installieren! Bitte zuerst Tampermonkey und dann FeedCrawler Helper (DJ) installieren! Die Click'n'Load-Automatik funktioniert nicht bei aktivem Linkgrabber. Warte noch {{time}} {{time == 1 ?'Sekunde':'Sekunden'}} auf hinzugefügte Links!
- Löschen

- Erneut hinzufügen Löschen

Verbinde mit My JDownloader...

Fehler bei Verbindung mit My JDownloader!
Downloadliste und Linksammler sind leer.

### Web-Suche

Suchen Leeren

Serie:

### Suchlisten

##

##### Filme

##### Filme/Serien (RegEx)

##### Staffeln

##

##### Serien

##### Serien (RegEx)

##### Staffeln (RegEx)

##### Staffeln

##

##### Staffeln

##

##### Dokus

##### Dokus (RegEx)

Speichern

### Einstellungen

##

##### Nutzername

##### Passwort

##### Gerätename

##### Autostart

##### Unterordner bei Download

##### Bereich zuklappen

##### Pakete pro Seite

##

##### Port

##### Prefix

##### Nutzername

##### Passwort

##### Suchintervall

##### FlareSolverr-URL

##### FlareSolverr-Proxy-URL

##### Ein Mirror genügt

##### Englische Releases hinzufügen

##### Mehrkanalton erzwingen

##

##### Rapidgator

##### Turbobit

##### Uploaded

##### Zippyshare

##### OBOOM

##### DDownload

##### FileFactory

##### Uptobox

##### 1Fichier

##### Filer

##### Nitroflare

##### IronFiles

##### Keep2Share

##

##### Pushbullet

##### Pushover

##### Home Assistant

##### Telegram

##

##### Ombi URL

##### Ombi API-Key

##

##### Auflösung

##### Suchtiefe

##### Filterliste

##### Auch per RegEx suchen

##### Ab IMDb-Wertung hinzufügen

##### IMDb hinzufügen ab Erscheinungsjahr

##### Zweisprachige Releases erzwingen

##### Nur Retail hinzufügen

##### Listeneintrag bei Retail streichen

##### 1080p-HEVC bevorzugen

##### Hoster-Fallback

##### Staffeln suchen

##### Auflösung der Staffeln

##### Staffelpakete erlauben

##### Quellart der Staffeln

##

##### Auflösung

##### Filterliste

##### Auch per RegEx suchen

##### Nur Retail hinzufügen

##### 1080p-HEVC bevorzugen

##### Hoster-Fallback

##### Staffeln suchen

##### Auflösung der Staffeln

##### Staffelpakete erlauben

##### Quellart der Staffeln

##

##### Staffeln suchen

##### Auflösung der Staffeln

##### Staffelpakete erlauben

##### Quellart der Staffeln

##

##### Auflösung

##### Filterliste

##### Auch per RegEx suchen

##### Hoster-Fallback

Speichern

### Hilfe

##

Der FeedCrawler Sponsors Helper ist ein Docker-Image, das SJ- und DJ-Captchas vollständig automatisiert löst und dem FeedCrawler entschlüsselt übergibt. Für den höchsten Automatisierungsgrad sollten entsprechend nur für diese Seiten die Hostnamen hinterlegt werden.

Captchas von FC lassen sich manuell per Webinterface/VNC lösen. Das Entschlüsseln und die Übergabe der Links übernimmt der FeedCrawler Sponsors Helper dann ebenfalls vollautomatisch.

Das Image steht ausschließlich aktiven Sponsoren zur Verfügung (daher der Name).
Die Freischaltung erfolgt manuell für aktive Sponsoren im dafür eingerichteten Github-Repo.

Benötigt wird ein Docker-Host mit mindestens 2 GB verfügbarem Arbeitsspeicher und ein Account beim unter Captchas beworbenen Captcha-Solver.

Kein aktiver Sponsor Aktiver Sponsor

##

Anti-Captcha.com (schnelles Lösen von ReCaptcha, etc. - auch im Browser)

##

Linksnappy.com (50 GB kostenfreies Startguthaben für DDownload, Rapidgator, 1Fichier, etc.)

##

##### Beispiele

Film.*.Titel.*
Sucht nach allen Filmen die mit Film beginnen und Titel enthalten.
.*-GROUP oder -GROUP
sucht nach allen Releases der GROUP.
.*1080p.*-GROUP
sucht nach allen Full-HD Releases der GROUP.
Film.Titel.*.DL.*.720p.*.BluRay.*-Group
sucht nach HD-BluRay Releases von Film Titel, zweisprachig und in 720p der GROUP.
Serien.Titel.*.S01.*.German.*.720p.*-GROUP
sucht nach Releases der GROUP von Staffel 1 der Serien Titel in 720p auf Deutsch.
Serien.Titel.*
sucht nach allen Releases von Serien Titel (nützlich, wenn man sonst HDTV aussortiert).
Serien.Titel.*.DL.*.720p.*
sucht nach zweisprachigen Releases in 720p von Serien Titel.
(?!(Diese|Andere)).*Serie.*.DL.*.720p.*-(GROUP|ANDEREGROUP)
sucht nach Serie (aber nicht Diese Serie oder Andere Serie), zweisprachig und in 720p und ausschließlich nach Releases von GROUP oder ANDEREGROUP.

All diese Regeln lassen sich beliebig kombinieren.
Falsche Regex-Einträge können allerdings die Feed-Suche verhindern!

Daher vorher beispielsweise auf RegExr.com testen, ob ein Eintrag matcht (Beispielrelease unter Text eintragen - Expression sollte etwas finden).

##

- {{ hostnames.fx }} (FX)
- {{ hostnames.sj }} (SJ)
- {{ hostnames.dj }} (DJ)
- {{ hostnames.sf }} (SF)

- {{ hostnames.ww }} (WW)
- {{ hostnames.nk }} (NK)
- {{ hostnames.by }} (BY)

##

Weitere Hinweise gibt es im Wiki.
{% endraw %}